package metadatainformer
import "k8s.io/client-go/metadata/metadatainformer"
Index ¶
- func NewFilteredMetadataInformer(client metadata.Interface, gvr schema.GroupVersionResource, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions TweakListOptionsFunc) informers.GenericInformer
- type SharedInformerFactory
- func NewFilteredSharedInformerFactory(client metadata.Interface, defaultResync time.Duration, namespace string, tweakListOptions TweakListOptionsFunc) SharedInformerFactory
- func NewSharedInformerFactory(client metadata.Interface, defaultResync time.Duration) SharedInformerFactory
- func NewSharedInformerFactoryWithOptions(client metadata.Interface, defaultResync time.Duration, options ...SharedInformerOption) SharedInformerFactory
- type SharedInformerOption
- type TweakListOptionsFunc
Functions ¶
func NewFilteredMetadataInformer ¶
func NewFilteredMetadataInformer(client metadata.Interface, gvr schema.GroupVersionResource, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions TweakListOptionsFunc) informers.GenericInformer
NewFilteredMetadataInformer constructs a new informer for a metadata type.
Types ¶
type SharedInformerFactory ¶
type SharedInformerFactory interface {
// Start initializes all requested informers. They are handled in goroutines
// which run until the stop channel gets closed.
(stopCh <-chan struct{})
// ForResource gives generic access to a shared informer of the matching type.
(gvr schema.GroupVersionResource) informers.GenericInformer
// WaitForCacheSync blocks until all started informers' caches were synced
// or the stop channel gets closed.
(stopCh <-chan struct{}) map[schema.GroupVersionResource]bool
// Shutdown marks a factory as shutting down. At that point no new
// informers can be started anymore and Start will return without
// doing anything.
//
// In addition, Shutdown blocks until all goroutines have terminated. For that
// to happen, the close channel(s) that they were started with must be closed,
// either before Shutdown gets called or while it is waiting.
//
// Shutdown may be called multiple times, even concurrently. All such calls will
// block until all goroutines have terminated.
()
}
SharedInformerFactory provides access to a shared informer and lister for dynamic client
func NewFilteredSharedInformerFactory ¶
func NewFilteredSharedInformerFactory(client metadata.Interface, defaultResync time.Duration, namespace string, tweakListOptions TweakListOptionsFunc) SharedInformerFactory
NewFilteredSharedInformerFactory constructs a new instance of metadataSharedInformerFactory. Listers obtained via this factory will be subject to the same filters as specified here.
func NewSharedInformerFactory ¶
func NewSharedInformerFactory(client metadata.Interface, defaultResync time.Duration) SharedInformerFactory
NewSharedInformerFactory constructs a new instance of metadataSharedInformerFactory for all namespaces.
func NewSharedInformerFactoryWithOptions ¶
func NewSharedInformerFactoryWithOptions(client metadata.Interface, defaultResync time.Duration, options ...SharedInformerOption) SharedInformerFactory
NewSharedInformerFactoryWithOptions constructs a new instance of metadataSharedInformerFactory with additional options.
type SharedInformerOption ¶
type SharedInformerOption func(*metadataSharedInformerFactory) *metadataSharedInformerFactory
SharedInformerOption defines the functional option type for metadataSharedInformerFactory.
func WithTransform ¶
func WithTransform(transform cache.TransformFunc) SharedInformerOption
WithTransform sets a transform on all informers.
type TweakListOptionsFunc ¶
type TweakListOptionsFunc func(*metav1.ListOptions)
TweakListOptionsFunc defines the signature of a helper function that wants to provide more listing options to API
Source Files ¶
informer.go interface.go
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 1 minute ago –
Tools for package owners.