package metadatalister
import "k8s.io/client-go/metadata/metadatalister"
Index ¶
Functions ¶
func NewRuntimeObjectShim ¶
func NewRuntimeObjectShim(lister Lister) cache.GenericLister
NewRuntimeObjectShim returns a new shim for Lister. It wraps Lister so that it implements cache.GenericLister interface
Types ¶
type Lister ¶
type Lister interface {
// List lists all resources in the indexer.
List(selector labels.Selector) (ret []*metav1.PartialObjectMetadata, err error)
// Get retrieves a resource from the indexer with the given name
Get(name string) (*metav1.PartialObjectMetadata, error)
// Namespace returns an object that can list and get resources in a given namespace.
Namespace(namespace string) NamespaceLister
}
Lister helps list resources.
func New ¶
func New(indexer cache.Indexer, gvr schema.GroupVersionResource) Lister
New returns a new Lister.
type NamespaceLister ¶
type NamespaceLister interface {
// List lists all resources in the indexer for a given namespace.
List(selector labels.Selector) (ret []*metav1.PartialObjectMetadata, err error)
// Get retrieves a resource from the indexer for a given namespace and name.
Get(name string) (*metav1.PartialObjectMetadata, error)
}
NamespaceLister helps list and get resources.
Source Files ¶
interface.go lister.go shim.go
- Version
- v0.31.10
- Published
- Jun 19, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 1 hour ago –
Tools for package owners.